@@ -1,3 +1,4 @@
+from datetime import datetime
 from django.db import models
 from entity.models import Entity, EntityQuerySet, AllEntityManager
 
@@ -6,9 +7,32 @@ class EntityActivationEvent(models.Model):
     """
     Models an event of an entity being activated or deactivated.
     """
-    entity = models.ForeignKey(Entity, help_text='The entity that was activated / deactivated')
-    time = models.DateTimeField(db_index=True, help_text='The time of the activation / deactivation')
-    was_activated = models.BooleanField(help_text='True if the entity was activated, false otherwise')
+    entity = models.ForeignKey(
+        Entity,
+        help_text='The entity that was activated / deactivated',
+        on_delete=models.CASCADE
+    )
+    time = models.DateTimeField(
+        db_index=True,
+        default=datetime.utcnow,
+        help_text='The time of the activation / deactivation'
+    )
+    creation_time = models.DateTimeField(
+        db_index=True,
+        default=datetime.utcnow,
+        help_text='The time that this entry was created')
+    updated_time = models.DateTimeField(
+        db_index=True,
+        default=datetime.utcnow,
+        help_text='The time that this entry was updated'
+    )
+    was_activated = models.BooleanField(
+        default=None,
+        help_text='True if the entity was activated, false otherwise'
+    )
+
+    class Meta:
+        app_label = 'entity_history'
 
 
 class EntityRelationshipActivationEvent(models.Model):
@@ -17,11 +41,40 @@ class EntityRelationshipActivationEvent(models.Model):
     are either created or deleted, however, we use the terms activated and deactivated for consistency.
     """
     sub_entity = models.ForeignKey(
-        Entity, related_name='+', help_text='The sub entity in the relationship that was activated / deactivated')
+        Entity,
+        related_name='+',
+        help_text='The sub entity in the relationship that was activated / deactivated',
+        on_delete=models.CASCADE
+
+    )
     super_entity = models.ForeignKey(
-        Entity, related_name='+', help_text='The super entity in the relationship that was activated / deactivated')
-    time = models.DateTimeField(db_index=True, help_text='The time of the activation / deactivation')
-    was_activated = models.BooleanField(help_text='True if the entity was activated, false otherwise')
+        Entity,
+        related_name='+',
+        help_text='The super entity in the relationship that was activated / deactivated',
+        on_delete=models.CASCADE
+    )
+    time = models.DateTimeField(
+        db_index=True,
+        default=datetime.utcnow,
+        help_text='The time of the activation / deactivation'
+    )
+    creation_time = models.DateTimeField(
+        db_index=True,
+        default=datetime.utcnow,
+        help_text='The time that this entry was created'
+    )
+    updated_time = models.DateTimeField(
+        db_index=True,
+        default=datetime.utcnow,
+        help_text='The time that this entry was updated'
+    )
+    was_activated = models.BooleanField(
+        default=None,
+        help_text='True if the entity was activated, false otherwise'
+    )
+
+    class Meta:
+        app_label = 'entity_history'
 
 
 def get_sub_entities_at_times(super_entity_ids, times, filter_by_entity_ids=None):
@@ -47,7 +100,7 @@ def get_sub_entities_at_times(super_entity_ids, times, filter_by_entity_ids=None
     for t in times:
         # Traverse the entity relationship events in ascending time, keeping track of if a sub entity was in a
         # relationship before time t
-        for er_event in filter(lambda er: er.time < t, er_events):
+        for er_event in [er for er in er_events if er.time < t]:
             if er_event.was_activated:
                 ers[(er_event.super_entity_id, t)].add(er_event.sub_entity_id)
             else:
@@ -75,7 +128,7 @@ def get_entities_at_times(times, filter_by_entity_ids=None):
 
     for t in times:
         # Traverse the entity events in ascending time, keeping track of if an entity was active before time t
-        for e_event in filter(lambda e: e.time < t, e_events):
+        for e_event in [e for e in e_events if e.time < t]:
             if e_event.was_activated:
                 es[t].add(e_event.entity_id)
             else:
